yakumo.keystone.v2.service.Manager

Package yakumo :: Package keystone :: Package v2 :: Module service :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for services on Identity V2 API

Nested Classes | [hide private]
| resource_class resource class for services on Identity V2 API

Instance Methods | [hide private]
yakumo.keystone.v2.service.Resource |
create(self, name=`'``__UNDEF__``'`, type=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Register a service | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``identity``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``OS-KSADM:service``'``
| _json_resources_key = ``'``OS-KSADM:services``'``
| _url_resource_path = ``'``/OS-KSADM/services``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, type=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Register a service Parameters: `name` (str) - Service name `type` (str) - Service type `description` (str) - Description `is_enabled` (str) - Whether the service is enabled or not Returns: yakumo.keystone.v2.service.Resource Created service Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('name', 'name', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('type', 'type', <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('description',
        'description',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('is_enabled',
        'enabled',
      ...